# Jodium

#### Installing

Install and update using pip:

```
$ pip install -U jodium
```

#### A Simple Example

```python
import jodium
```

#### Links

- Documentation: [https://github.com/MarkHoo/jodium](https://github.com/MarkHoo/jodium)
- PyPI Releases: [https://pypi.org/project/jodium/](https://pypi.org/project/jodium/)
- Source Code: [https://github.com/MarkHoo/jodium](https://github.com/MarkHoo/jodium)
- Issue Tracker: [https://github.com/MarkHoo/jodium/issues](https://github.com/MarkHoo/jodium/issues)
- Website: [https://pypi.org/project/jodium/](https://pypi.org/project/jodium/)

